@@ -29,12 +29,9 @@ import logging
 import gzip
 import os
 import re
-try:
-    # Python 3 workaround
-    import urllib.request as urllib
-except:
-    import urllib
+from six.moves.urllib.request import urlretrieve
 
+import datetime
 # Constants for directory structure
 SVAR = "var"
 SCACHE = "cache"
@@ -69,9 +66,13 @@ class Repository(object):
                          True
     :param checkForUpdates: Flag used to update the back end after setup based
                             on the remote configuration
+    :param repo_additional_information: Dictionary with extra information
+                                        about the repository.
+                                        e.g remote time of last update,
+                                        local time of last update
     """
     def __init__(self, name, url, repocachedir, backendList, setupBackend=True,
-                 checkForUpdates=True):
+                 checkForUpdates=True, repo_additional_information=None):
         # These are hardwired dependencies in RPM.
         # we do not need to care about them...
         log.info("Initializing repository: %s / %s" % (name, url))
@@ -94,10 +95,17 @@ class Repository(object):
         self.findLatestMatchingRequire = None
         self.getAllPackages = None
         self.getAllProvides = None
-
         # Loading the appropriate backend
         # if requested
         if setupBackend:
+            if repo_additional_information:
+                r_last_update = repo_additional_information[
+                    'remote_last_update']
+                l_last_update = repo_additional_information[
+                    'local_last_update']
+                if r_last_update <= l_last_update and checkForUpdates is True:
+                    log.info("Backend did not change, using local metadata")
+                    checkForUpdates = False
             if checkForUpdates:
                 self.setupBackendFromRemote()
             else:
@@ -230,13 +238,10 @@ class Repository(object):
     def _getRemoteMetadata(self):
         """ Gets the remote repomd file """
         log.info("NET - Getting remote metadata for %s" % self.name)
-        try:
-            import urllib2
-        except:
-            # Python 3 workaround
-            from urllib import request as urllib2
+        from six.moves.urllib.request import urlopen
+
         ret = None
-        response = urllib2.urlopen(self.repomdurl)
+        response = urlopen(self.repomdurl)
         data = response.read()
         if data is not None:
             ret = self._checkRepoMD(data)
@@ -315,7 +320,7 @@ class RepositoryXMLBackend(object):
         :param url: the url of the xml database
         """
         log.info("NET - Downloading latest version of XML DB")
-        urllib.urlretrieve(url, self.mPrimary)
+        urlretrieve(url, self.mPrimary)
 
     def hasDB(self):
         """ Check whether the DB is there """
@@ -642,7 +647,7 @@ class RepositorySQLiteBackend(object):
         :param url: the url of the xml database
         """
         log.debug("NET - Downloading latest version of SQLite DB")
-        urllib.urlretrieve(url, self.mPrimary)
+        urlretrieve(url, self.mPrimary)
 
         log.debug("Decompressing latest version of SQLite DB")
         if os.path.exists(self.mPrimaryUncompressed):
@@ -878,16 +883,19 @@ class RepositorySQLiteBackend(object):
              p.rpm_group, p.arch, p.location_href
              from packages p, provides r
              where p.pkgkey = r.pkgkey
-             and r.name = ?
-             and r.version = ? """
+             and r.name = ? """
 
-        if provide.release is not None:
-            sq += " and r.release = ? "
-            res = cursor.execute(sq, [provide.name,
-                                      provide.version,
-                                      provide.release])
+        if provide.version is not None:
+            sq += " and r.version = ? "
+            if provide.release is not None:
+                sq += " and r.release = ? "
+                res = cursor.execute(sq, [provide.name,
+                                          provide.version,
+                                          provide.release])
+            else:
+                res = cursor.execute(sq, [provide.name, provide.version])
         else:
-            res = cursor.execute(sq, [provide.name, provide.version])
+            res = cursor.execute(sq, [provide.name])
 
         # Getting the results
         for (pkgkey, pname, version, release,
@@ -927,8 +935,11 @@ class LbYumClient(object):
     :param repourls: The list of of the repository urls
     :param checkForUpdates: Flag used to update the back end after setup based
                             on the remote configuration
+    :param: repositories_extra_infos: Dictionary of additional info per repo name
+                        (key: reponame, value: additional info per repo)
     """
-    def __init__(self, localConfigRoot, repourls, checkForUpdates=True):
+    def __init__(self, localConfigRoot, repourls, checkForUpdates=True,
+                 repositories_extra_infos={}):
         """ Constructor for the client """
         # Basic initializations
         self.repourls = repourls
@@ -940,9 +951,10 @@ class LbYumClient(object):
         # At this point we have the repo names and URLs in self.repourls
         # we know connect to them to get the best method to get the appropriate
         # files
-        self._initializeRepositories(repourls, checkForUpdates,
-                                     [RepositorySQLiteBackend,
-                                      RepositoryXMLBackend])
+        self._initializeRepositories(
+            repourls, checkForUpdates,
+            [RepositorySQLiteBackend, RepositoryXMLBackend],
+            repositories_extra_infos=repositories_extra_infos)
 
     def addRepository(self, repository):
         """ Adds a repository manually, useful for testing
@@ -1128,7 +1140,7 @@ class LbYumClient(object):
         return requiredlist
 
     def _initializeRepositories(self, repourls, checkForUpdates,
-                                knownBackends):
+                                knownBackends, repositories_extra_infos={}):
         """ Initilize the repositories given their URLS """
 
         self.repourls = repourls
@@ -1139,13 +1151,15 @@ class LbYumClient(object):
             # Getting the main parameters for the repository:
             # URL and cache directory
             repourl = self.repourls[repo]
+            extra_info = repositories_extra_infos.get(repo, None)
             repocachedir = os.path.join(self.lbyumcache, repo)
             if not os.path.exists(repocachedir):
                 os.makedirs(repocachedir)
 
             try:
                 rep = Repository(repo, repourl, repocachedir,
-                                 knownBackends, True, checkForUpdates)
+                                 knownBackends, True, checkForUpdates,
+                                 repo_additional_information=extra_info)
                 log.debug("Repository %s created" % repo)
                 # Now adding the repository to the map
                 self.repositories[repo] = rep
