@@ -74,13 +74,16 @@ class Installer(object):
                     <siteroot>/tmp/
     :param pool_size: The pool size of the download thread pool
     :param stric: Flag used to stop an action if a dependency is not satisfied
+    :param forceCheckForUpdates: Flag used to skip the remote last update
+                                 time and force the update of the meta info
     '''
 
     def __init__(self, siteroot, config=None,
                  localRPMcache=None, disableYumCheck=False,
                  chained_db_list=[], nodeps=False,
                  tmp_dir=None, pool_size=5,
-                 strict=True):
+                 strict=True,
+                 forceCheckForUpdates=False):
         '''Class to install a set of packages to a specific area
         '''
         self.log = logging.getLogger(__name__)
@@ -88,7 +91,7 @@ class Installer(object):
         self._lcgDir = os.path.join(self._siteroot, "lcg")
         if config is None:
             from lbinstall.LHCbConfig import Config
-            config = Config()
+            config = Config(self._siteroot)
         self._config = config
         self._nodeps = nodeps
         self.pool_size = pool_size
@@ -97,8 +100,11 @@ class Installer(object):
         self.__installArea = InstallArea(self._config, self._siteroot,
                                          tmp_dir=tmp_dir)
         self._lbYumClient = self.__installArea \
-                                .createYumClient(not disableYumCheck)
+                                .createYumClient(
+            not disableYumCheck, forceCheckForUpdates=forceCheckForUpdates)
         self._chainedDBManger = self.__installArea.createChainedDBManager()
+        for chained_db in chained_db_list:
+            self._chainedDBManger.addDb(chained_db)
         self._localDB = self.__installArea.createDBManager(
             self._chainedDBManger)
         self._relocateMap = self.__installArea.getRelocateMap()
@@ -108,8 +114,7 @@ class Installer(object):
 
         if localRPMcache is not None:
             self._localRPMcache = localRPMcache
-        for chained_db in chained_db_list:
-            self._chainedDBManger.addDb(chained_db)
+
         self.strict = strict
 
     # Various utilities to query the yum database
@@ -329,11 +334,10 @@ class Installer(object):
             rpmtoinstall = rpms_to_install_tmp
         else:
             for p in packagelist:
-                if not self._localDB.isPackagesInstalled(p):
+                if not self._localDB.isPackagesInstalled(p) or ignoreInstalled:
                     rpmtoinstall.append(p)
                 else:
                     self.log.warning("%s already installed" % p.rpmName())
-
         if ignoreInstalled:
             return rpmtoinstall
         for package in rpmtoinstall:
@@ -940,11 +944,7 @@ class Installer(object):
         if location is None:
             location = self._tmpdir
 
-        try:
-            # Python 3 workaround
-            import urllib.request as urllib
-        except:
-            import urllib
+        from six.moves.urllib.request import urlretrieve
 
         to_return = []
         for pack in installlist:
@@ -975,7 +975,7 @@ class Installer(object):
                                                             tmp_name))
 
                     try:
-                        urllib.urlretrieve(pack.url(), tmp_name)
+                        urlretrieve(pack.url(), tmp_name)
                         fileisok = self._checkRpmFile(tmp_name)
                         if fileisok or fileisok is None:
                             shutil.copy(tmp_name, full_filename)
@@ -1142,7 +1142,15 @@ class Installer(object):
         """
         for rpm in rpms_list:
             # Convert from None to latest version and release
-            tmp = self.remoteFindPackage(rpm[0], rpm[1], rpm[2])[0]
+            tmp = self.remoteFindPackage(rpm[0], rpm[1], rpm[2])
+
+            if not tmp:
+
+                raise Exception("Package %s was not found in any repository! "
+                                "Please specify one or more "
+                                "valid packages!" % '-'.join(
+                    [x for x in rpm if x]))
+            tmp = tmp[0]
             package = (tmp.name, tmp.version, tmp.release)
 
             local_packages = self.localFindPackages(package[0],
@@ -1302,41 +1310,6 @@ class Installer(object):
                      overwrite=True, justdb=justdb,
                      ignoredInstalledList=ignoredInstalledList)
 
-    # Package query
-    # ############################################################################
-    def queryPackages(self, nameregexp=None,
-                      versionregexp=None,
-                      releaseregexp=None):
-        ''' Implement the listing of packages
-
-        :param nameRegexp: Regex for the name of the package
-        :param versionRegexp: Regex for the version of the package
-        :param releaseRegexp: Regex for the release of the package
-        '''
-        for l in sorted(list(self.remoteListPackages(nameregexp,
-                                                     versionregexp,
-                                                     releaseregexp))):
-            print(l.rpmName())
-
-    # Providers query
-    # ############################################################################
-    def queryProviders(self, nameregexp=None,
-                       versionregexp=None,
-                       releaseregexp=None):
-        ''' Implement the listing of provides
-
-        :param nameRegexp: Regex for the name of the package
-        :param versionRegexp: Regex for the version of the package
-        :param releaseRegexp: Regex for the release of the package
-        '''
-        allpackages = set()
-        for l in sorted(list(self.remoteListProvides(nameregexp))):
-            for p in self.remoteFindPackage(l.name,
-                                            l.version,
-                                            l.release):
-                allpackages.add(p)
-        for l in sorted(allpackages):
-            print(l.rpmName())
 
     def checkPackagesFromTuples(self, rpms_to_verify):
         ''' Implement the verifiy method of packages
