@@ -100,6 +100,7 @@ class LbInstallClient(object):
         self.query_provides = False
         self.is_regex = False
         self.overwrite = None
+        self.forceCheckForUpdates = False
         self.tmp_dir = None
         self.pool_size = 5
 
@@ -156,6 +157,11 @@ class LbInstallClient(object):
                           action="store_true",
                           help="Disables the fail if a dependency cannot "
                                "be resolved")
+        parser.add_option('--skip-date-check',
+                          dest="forceCheckForUpdates",
+                          default=False,
+                          action="store_true",
+                          help="Skip the date check for the repo last update")
         parser.add_option('--overwrite',
                           dest="overwrite",
                           default=False,
@@ -196,7 +202,7 @@ class LbInstallClient(object):
                           action="store",
                           help="specify a custom tmp directory instead of "
                                "the default $SITEROOT/tmp")
-        parser.add_option('--chained_database',
+        parser.add_option('--chained_installarea',
                           dest="chained_db",
                           default=None,
                           action="store",
@@ -297,6 +303,10 @@ class LbInstallClient(object):
                 self.query_provides = True
             else:
                 self.query_provides = False
+            if opts.forceCheckForUpdates:
+                self.forceCheckForUpdates = True
+            else:
+                self.forceCheckForUpdates = False
             if opts.is_regex:
                 self.is_regex = True
             else:
@@ -319,21 +329,21 @@ class LbInstallClient(object):
             # is used skipConfig allows returning a config with the LHCb
             # repositories
             from lbinstall.LHCbConfig import Config
-            conf = Config(opts.repourl, skipConfig=opts.nolhcbrepo)
+            conf = Config(siteroot, opts.repourl,
+                          skipDefaultConfig=opts.nolhcbrepo)
 
             #
             for i, url in enumerate(opts.extrarepo):
                 conf.repos["extrarepo_%d" % i] = {"url": url}
 
             # Initializing the installer
-            self.installer = Installer(siteroot=siteroot,
-                                       disableYumCheck=opts.noyumcheck,
-                                       chained_db_list=chained_db_list,
-                                       nodeps=nodeps,
-                                       config=conf,
-                                       tmp_dir=self.tmp_dir,
-                                       pool_size=self.pool_size,
-                                       strict=self.strict)
+            self.installer = Installer(
+                siteroot=siteroot, disableYumCheck=opts.noyumcheck,
+                chained_db_list=chained_db_list,
+                nodeps=nodeps, config=conf,
+                tmp_dir=self.tmp_dir, pool_size=self.pool_size,
+                strict=self.strict,
+                forceCheckForUpdates=self.forceCheckForUpdates)
             if opts.rpmcache:
                 for cachedir in opts.rpmcache:
                     self.installer.addDirToRPMCache(abspath(cachedir))
@@ -381,6 +391,10 @@ class LbInstallClient(object):
 
         # Now executing the command
         if mode == LbInstallClient.MODE_QUERY:
+            # Test if no query is present. If show, add a "empty" query
+            # in order to display the entire database.
+            if len(args) == 1:
+                args.append('')
             # Mode that list packages according to a regexp
             if not self.is_regex:
                 new_args = []
@@ -390,9 +404,25 @@ class LbInstallClient(object):
                 args = [args[0]]
                 args.extend(new_args)
             if self.query_provides:
-                self.installer.queryProviders(*args[1:])
+                allpackages = set()
+                for l in sorted(list(
+                        self.installer.remoteListProvides(args[1]))):
+                    for p in self.installer.remoteFindPackage(
+                            l.name,  l.version, l.release):
+                        allpackages.add(p)
+                for l in sorted(allpackages):
+                    print(l.rpmName(),  l.repository.name)
             else:
-                self.installer.queryPackages(*args[1:])
+                nameregexp = args[1]
+                versionregexp = None
+                releaseregexp = None
+                if len(args) > 2:
+                    versionregexp = args[2]
+                if len(args) > 3:
+                    versionregexp = args[3]
+                for l in sorted(list(self.installer.remoteListPackages(
+                        nameregexp, versionregexp, releaseregexp))):
+                    print(l.rpmName(),  l.repository.name)
         elif mode == LbInstallClient.MODE_LIST:
             # Mode that list packages according to a regexp
             results = self.installer.listInstalledPackages(* args[1:])
@@ -428,6 +458,13 @@ class LbInstallClient(object):
                     rpmname = m.group(1)
                     version = m.group(2)
                     release = m.group(3)
+                else:
+                    # Special cases e.g CMT-v1r20p20090520-1
+                    m = re.match("(.*)-(.*)-(\d+)$", rpmname)
+                    if m is not None:
+                        rpmname = m.group(1)
+                        version = m.group(2)
+                        release = m.group(3)
                 rpms_list.append((rpmname, version, release))
                 i = i + 1
                 first_pass = False
