@@ -37,7 +37,7 @@ class Test(unittest.TestCase):
         self.configFile = "%s/etc/chaining_infos.json" % self.siteroot
         if os.path.exists(dbpath):
             os.unlink(dbpath)
-        self.config = Config(None, skipConfig=True)
+        self.config = Config(self.siteroot, None, skipDefaultConfig=True)
         self.config.repos['lhcbdev'] = {'url': 'http://lhcb-rpm.web.cern.ch/'
                                                'lhcb-rpm/lhcbdevtests'}
         self._mgr = Installer(self.siteroot, config=self.config,
